package com.akamai.ampdemo;

import android.app.Activity;
import android.content.Intent;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.widget.ProgressBar;

import com.akamai.amp.ads.AdsCount;
import com.akamai.amp.ads.AdsInfo;
import com.akamai.amp.ads.IAdsComponentListener;
import com.akamai.amp.ads.ima.AmpIMAManager;
import com.akamai.amp.ads.ima.IMA;
import com.akamai.amp.analytics.mux.AmpMuxDataAnalyticsTracker;
import com.akamai.amp.analytics.mux.MuxData;
import com.akamai.amp.analytics.mux.MuxDataTracker;
import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.elements.MediaResource;
import com.akamai.amp.media.errors.ErrorType;
import com.akamai.amp.uimobile.media.MediaPlayerController;


public class PlayerActivity extends Activity
        implements VideoPlayerContainer.VideoPlayerContainerCallback, IAdsComponentListener {

    private static final String LOG_TAG = PlayerActivity.class.getSimpleName();
    private static final String AMP_LICENSE = "duFlD_z1uYSAsd80HVwysOeY-OaKTMZpQriNZsSC05QCRZVuu66gt4eNBcZiVSvW0DVjNh14CvwtonAkEMHDTA==";

    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private ProgressBar progressBar;
    private MediaPlayerController mediaPlayerController;

    private AmpIMAManager ads;
    private AmpMuxDataAnalyticsTracker analytics;

    private Video videoSelected;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_player);

        Intent intent = getIntent();
        videoSelected = (Video) intent.getSerializableExtra("videoSelected");

        progressBar = findViewById(R.id.progressBar);
        videoPlayerContainer = findViewById(R.id.playerViewCtrl);
        mediaPlayerController = findViewById(R.id.playerControls);
        mediaPlayerController.hideFullscreenButton();
        videoPlayerContainer.addVideoPlayerContainerCallback(this);
        videoPlayerContainer.prepareResource(videoSelected.videoURL);
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.i(LOG_TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceError(ErrorType errorType, Exception exception) {
        Log.e(LOG_TAG, "onResourceError()");
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setLicense(AMP_LICENSE);
        videoPlayerView.setLogEnabled(true);
        videoPlayerView.setKeepScreenOn(true);
        mediaPlayerController.setVideoPlayerContainer(videoPlayerContainer);
        videoPlayerView.setProgressBarControl(progressBar);

        initGoogleAds();
        initMux();

        videoPlayerView.play(mediaResource);
    }

    private void initMux() {
        MuxData muxData = MuxHelper.createMuxData();
        analytics = MuxDataTracker.create(videoPlayerView, muxData);

        if (ads != null) {
            IAdsComponentListener adsListener = analytics.getiAdsComponentListener();
            ads.addEventsListener(adsListener);
        }
    }

    private void initGoogleAds() {
        String adsUrl = videoSelected.adsUrl;
        if (adsUrl == null) return;

        ads = IMA.create(this).buildClientSideManager();
        ads.setVideoPlayerContainer(videoPlayerContainer);
        ads.setVideoPlayerView(videoPlayerView);
        ads.addEventsListener(this);
        ads.setAdsUrl(adsUrl);
    }


    //It's mandatory to let the SDK know when the app goes and comes to the background

    @Override
    protected void onPause() {
        Log.d(LOG_TAG, "onPause");
        if (videoPlayerView != null) videoPlayerView.onPause();
        super.onPause();
    }

    @Override
    protected void onResume() {
        Log.d(LOG_TAG, "onResume");
        if (videoPlayerView != null) videoPlayerView.onResume();
        super.onResume();
    }

    @Override
    protected void onDestroy() {
        Log.d(LOG_TAG, "onDestroy");
        if (videoPlayerView != null) videoPlayerView.onDestroy();
        super.onDestroy();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        if (analytics != null) {
            analytics.onConfigurationChanged(newConfig);
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        return false;
    }

    @Override
    public void onAdsError(String s) {
        Log.d(LOG_TAG, "onAdsError " + s);
    }

    @Override
    public void onPauseContentRequested() {
        mediaPlayerController.showControlBar(false);
    }

    @Override
    public void onResumeContentRequested() {
        mediaPlayerController.showControlBar(true);
        Log.d(LOG_TAG, "onResumeContentRequested");
    }

    @Override
    public void onListenerRegistered() {
        Log.d(LOG_TAG, "onListenerRegistered");
    }

    @Override
    public void onAdsInitialized() {
        Log.d(LOG_TAG, "onAdsInitialized");
    }

    @Override
    public void onAdsLoaded(AdsCount adsCount) {
        Log.d(LOG_TAG, "onAdsLoaded " + adsCount);
    }

    @Override
    public void onAdsStarted(AdsInfo ads) {
        Log.i(LOG_TAG, "onAdsStarted");
    }

    @Override
    public void onAdsPaused() {
        Log.d(LOG_TAG, "onAdsPaused");
    }

    @Override
    public void onAdsResumed() {
        Log.d(LOG_TAG, "onAdsResumed");
    }

    @Override
    public void onAdBreakStarted() {
        Log.d(LOG_TAG, "onAdBreakStarted");
    }

    @Override
    public void onAdBreakEnded() {
        Log.d(LOG_TAG, "onAdBreakEnded");
    }

    @Override
    public void onAdsEnded() {
        Log.d(LOG_TAG, "onAdsEnded");
    }

    @Override
    public void onAllPostrollsEnded() {
        Log.d(LOG_TAG, "onAllPostrollsEnded");
    }

    @Override
    public void onAdsTrackProgress(int i) {
        Log.d(LOG_TAG, "onAdsTrackProgress " + i);
    }

    @Override
    public void onAdsPlayheadUpdate(int i) {
        Log.d(LOG_TAG, "onAdsPlayheadUpdate " + i);
    }

    @Override
    public void onAdEvent() {
        Log.d(LOG_TAG, "onAdEvent");
    }

    @Override
    public void onAdsTapped() {
        Log.d(LOG_TAG, "onAdsTapped");
    }

    @Override
    public void onAdSkipped() {
        Log.d(LOG_TAG, "onAdsTapped");
    }

}
