package com.akamai.amp.demo;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.widget.Toast;

import com.akamai.amp.AmpPlayer;
import com.akamai.amp.ads.fban.AmpFacebookAudienceNetworkManager;
import com.akamai.amp.ads.freewheel.AmpFreewheelManager;
import com.akamai.amp.ads.ima.AmpDAIManager;
import com.akamai.amp.ads.ima.AmpIMAManager;
import com.akamai.amp.ads.ima.IMA;
import com.akamai.amp.ads.yospace.AmpYospaceManager;
import com.akamai.amp.analytics.adobeheartbeat.AdobeHeartbeat;
import com.akamai.amp.analytics.adobeheartbeat.AmpAdobeHeartbeatAnalyticsTracker;
import com.akamai.amp.analytics.akamaimedia.AmpAkamaiMediaAnalyticsTracker;
import com.akamai.amp.analytics.akamaimedia.MediaAnalytics;
import com.akamai.amp.analytics.comscorestreamsense.AmpComscoreStreamsenseAnalyticsTracker;
import com.akamai.amp.analytics.comscorestreamsense.ComscoreStreamsense;
import com.akamai.amp.analytics.firebase.AmpFirebaseAnalyticsTracker;
import com.akamai.amp.analytics.firebase.FireBase;
import com.akamai.amp.analytics.googleanalytics.AmpGoogleAnalyticsTracker;
import com.akamai.amp.analytics.googleanalytics.GoogleAnalytics;
import com.akamai.amp.analytics.nielsenanalytics.AmpNielsenDcrAnalyticsTracker;
import com.akamai.amp.analytics.nielsenanalytics.NielsenDcr;
import com.akamai.amp.demo.helpers.ads.FreewheelHelper;
import com.akamai.amp.demo.helpers.analytics.AkamaiMediaHelper;
import com.akamai.amp.demo.helpers.analytics.FirebaseHelper;
import com.akamai.amp.demo.helpers.analytics.GoogleHelper;
import com.akamai.amp.demo.helpers.analytics.HeartbeatHelper;
import com.akamai.amp.demo.helpers.analytics.NielsenHelper;
import com.akamai.amp.demo.helpers.analytics.StreamsenseHelper;
import com.akamai.amp.uimobile.generic.listeners.IMediaPlayerControllerListener;
import com.comscore.streaming.ContentMetadata;

import static com.akamai.amp.AmpPlayerControlsOverlay.Mode;
import static com.akamai.amp.AmpPlayerControlsOverlay.State;

//import com.akamai.amp.rendering360.VR360;


public class MainActivity extends Activity {

    /*
     * AMP's license takes into account the package name of your app and the expiration day.
     * This date can't be extended from Akamai's side, so be sure NOT to hardcode your license
     * into the app
     */
    private static final String AMP_LICENSE = "spOJe2QdcF0OLMdK8AL_Bewz7oQxb3MfrA3h__NT1ZJWyOmfzMWKlDgnraRTu9pUfmet8qWjmNR2lLBr3xsgrQ==";

    /*
     * Sample test streams
     */
    private static final String HLS_VOD = "https://media-demo-host.akamaized.net/test/video/kluge/hls/all.m3u8";
    private static final String HLS_LIVE = "http://multiformatlive-f.akamaihd.net/i/demostream_1@2131/master.m3u8";
    String mAds = "https://pubads.g.doubleclick.net/gampad/ads?sz=640x480&iu=/124319096/external/ad_rule_samples&ciu_szs=300x250&ad_rule=1&impl=s&gdfp_req=1&env=vp&output=vmap&unviewed_position_start=1&cust_params=deployment%3Ddevsite%26sample_ar%3Dpremidpostpod&cmsid=496&vid=short_onecue&correlator=";


    /*
     * AMP's main class
     */
    private AmpPlayer amp;

    /*
     * Usually an app has a single ad provider.
     * The parent interface of all the following is com.akamai.amp.ads.IAdsPlugin
     */
    private AmpIMAManager imaAds;
    private AmpDAIManager daiAds;
    private AmpFreewheelManager freewheelAds;
    private AmpYospaceManager yospaceAds;
    private AmpFacebookAudienceNetworkManager facebookAds;

    /*
     * Usually an app has several analytics trackers.
     * The parent class of all the following is com.akamai.amp.analytics.AnalyticsTracker
     */
    private AmpAkamaiMediaAnalyticsTracker akamaiMediaAnalytics;
    private AmpComscoreStreamsenseAnalyticsTracker streamsenseAnalytics;
    private AmpAdobeHeartbeatAnalyticsTracker heartbeatAnalytics;
    private AmpNielsenDcrAnalyticsTracker nielsenAnalytics;
    private AmpGoogleAnalyticsTracker googleAnalytics;

    private AmpFirebaseAnalyticsTracker firebaseAnalytics;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // AMP's main class instantiation
        amp = findViewById(R.id.amp);
        amp.configure(this, AMP_LICENSE, customButtonsCallback());
        amp.configureVisually(State.INLINE_PLAYER, Mode.INLINE, true, true);


        // Ads providers
        imaAds = IMA.create(this).buildClientSideManager();
        //  daiAds = IMA.create(this).buildServerSideManager();

        freewheelAds = FreewheelHelper.createManager(this);
        //yospaceAds = YospaceHelper.createManager(this);
        //acebookAds = FacebookHelper.createManager();


        // Analytics providers
        akamaiMediaAnalytics = MediaAnalytics.create(AkamaiMediaHelper.buildData());
        if (amp.getVideoPlayerView() != null) {
            streamsenseAnalytics = ComscoreStreamsense.create(StreamsenseHelper.buildData(amp.getVideoPlayerView()));
            ContentMetadata contentMetadata = StreamsenseHelper.buildContentMetadata();
            streamsenseAnalytics.setContentMetadata(contentMetadata);
        }
        heartbeatAnalytics = AdobeHeartbeat.create(HeartbeatHelper.buildData());
        nielsenAnalytics = NielsenDcr.create(NielsenHelper.buildData());
        googleAnalytics = GoogleAnalytics.create(GoogleHelper.buildData());
        firebaseAnalytics = FireBase.create(FirebaseHelper.buildData());

        // Setting the plugins to AMP
        // Notice that AMP is set to function with a single ad provider and multiple analytics providers

        //amp.setAnalyticsPlugins(streamsenseAnalytics);
        amp.setPlugins(imaAds);

        if (amp.getVideoPlayerView() != null) {
            amp.getVideoPlayerView().setLogEnabled(true);
        }

        // Start DAI Playback
        //amp.prepareLiveStreamWithServerAds("sN_IYUG8STe1ZzhIIE_ksA");

        // Start playback
        // Notice this is not immediate, as the URL has to be retrieved and the stream has to be prepared)
        amp.prepare()
                .withClientSideIMA(mAds)
                .withStream(HLS_VOD)
                .init();

        //Start 360 or VR playback
       /* amp.prepare().withStream("http://cache.utovr.com/201508270528174780.m3u8")
                .withCustomRenderer(VR360.create(this),
                        VR360.INTERACTIVE_MODE_CARDBOARD_MOTION_WITH_TOUCH,
                        VR360.DISPLAY_MODE_NORMAL,
                        VR360.PROJECTION_MODE_SPHERE).init();*/

    }


    /*
     * AMP needs to be aware of the Android lifecycle events.
     * The minimum necessary are onResume(), onPause() and onDestroy().
     */

    @Override
    public void onResume() {
        if (amp != null) amp.onResume();
        super.onResume();
    }

    @Override
    public void onPause() {
        if (amp != null) amp.onPause();
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        if (amp != null) amp.onDestroy();
        super.onDestroy();
    }


    /*
     * This is a non mandatory sample of how to implement custom actions on specific UI clicks
     */
    private IMediaPlayerControllerListener customButtonsCallback() {
        return buttonId -> {
            switch (buttonId) {
                case IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_CLOSE:
                    showToast("CLOSE");
                    break;
                case IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_SHARE:
                    showToast("SHARE");
                    break;
                default:
                    break;
            }
        };
    }

    private void showToast(String message) {
        Context context = getApplication().getApplicationContext();
        Toast.makeText(context, message, Toast.LENGTH_LONG).show();
    }

}
